@@ -21,6 +21,7 @@ import json
 import random
 import re
 import urllib
+import tempfile
 
 import osrframework.utils.browser as browser
 import osrframework.utils.general as general
@@ -69,27 +70,32 @@ class Platform(object):
     def create_url(self, word, mode="phonefy"):
         """Method to create the URL replacing the word in the appropriate URL
 
+        Depending on the module it returns the corresponding URL. However,
+        a special keyword can be provided as mode ("base") to use a different
+        URL instead. This is useful when the check is performed towards a
+        different platform (e. g., tweettunnel.com) but the URI to be shown is
+        expected to be the original one (e. g., twitter.com).
+
         Args:
             word (str): Word to be searched.
             mode (str): Mode to be executed.
 
         Returns:
-            The URL to be queried.
+            The URL to be queried. It returns None if no base has been provided.
         """
         try:
-            return self.modes[mode]["url"].replace("{placeholder}", word)
-        except:
             if mode == "base":
                 if word[0] == "/":
-                    return self.baseURL + word[1:], word
+                    return self.baseURL + word[1:]
                 else:
                     return self.baseURL + word
             else:
                 try:
-                    return self.url[mode].replace("<"+mode+">", word)
+                    return self.modes[mode]["url"].replace("{placeholder}", word)
                 except:
-                    pass
-        return None
+                    return self.url[mode].replace("<"+mode+">", word)
+        except:
+            return None
 
     def launch_query_for_mode(self, query=None, mode=None):
         """Method that launches an i3Browser to collect data
@@ -120,9 +126,18 @@ class Platform(object):
             else:
                 # Accessing the resources
                 data = i3Browser.recover_url(qURL)
+
+            try:
+                if self.modes[mode]["debug"]:
+                    with open(os.path.join(tempfile.gettempdir(), self.platformName) + ".html", "w") as file:
+                        print(f"DEBUG mode is active for '{general.emphasis(self.platformName)}'. Data grabbed saved to: '{general.warning(file.name)}'")
+                        file.write(data)
+            except:
+                pass
+
             return data
         except KeyError:
-            print(general.error("[*] '{}' is not a valid mode for this wrapper ({}).".format(mode, self.__class__.__name__)))
+            print(general.error("\t[*] '{}' is not a valid mode for this wrapper ({}).".format(mode, self.__class__.__name__)))
 
         return None
 
@@ -350,11 +365,11 @@ class Platform(object):
             ]
         """
         if self.check_mailfy(query, **kwargs):
-            expandedEntities = general.expand_entities_from_email(query)
+            expanded_entities = general.expand_entities_from_email(query)
             r = {
                 "type": "com.i3visio.Profile",
                 "value": self.platformName + " - " + query,
-                "attributes": expandedEntities + [
+                "attributes": expanded_entities + [
                     {
                         "type": "com.i3visio.Platform",
                         "value": self.platformName,
@@ -401,7 +416,7 @@ class Platform(object):
             A list of elements to be appended.
         """
         results = []
-        print(f"[*] Launching search using the {self.__class__.__name__} module...")
+        print(f"\t[*] Launching search using the {self.__class__.__name__} module...")
         test = self.check_searchfy(query, **kwargs)
 
         if test:
@@ -644,7 +659,13 @@ class Platform(object):
             # Appending platform URI
             aux = {}
             aux["type"] = "com.i3visio.URI"
-            aux["value"] = self.create_url(word=query, mode="usufy")
+
+            uri = self.create_url(word=query, mode="base")
+            if uri:
+                aux["value"] = uri
+            else:
+                aux["value"] = self.create_url(word=query, mode="usufy")
+
             aux["attributes"] = []
             r["attributes"].append(aux)
             # Appending the alias
